@@ -2,7 +2,9 @@
 # This file is based on this gist:
 # http://code.activestate.com/recipes/134892/
 # So real authors are DannyYoo and company.
+from __future__ import absolute_import
 import sys
+from . import key
 
 
 if sys.platform.startswith('linux'):
@@ -17,14 +19,13 @@ else:
 
 def readkey(getchar_fn=None):
     getchar = getchar_fn or readchar
-    c1 = getchar()
-    if ord(c1) != 0x1b:
-        return c1
-    c2 = getchar()
-    if ord(c2) != 0x5b:
-        return c1 + c2
-    c3 = getchar()
-    if ord(c3) != 0x33:
-        return c1 + c2 + c3
-    c4 = getchar()
-    return c1 + c2 + c3 + c4
+    buffer = getchar(True)
+
+    while True:
+        if buffer not in key.ESCAPE_SEQUENCES:
+            return buffer
+        c = getchar(True)
+        if c is None:
+            return buffer
+        buffer += c
+    return buffer
